@@ -8,7 +8,6 @@ extensions = [
     "sphinx.ext.intersphinx",
     "sphinx_autodoc_typehints",
     "sphinx_tabs.tabs",
-    "sphinxcontrib.asyncio",
 ]
 
 templates_path = ["_templates"]
@@ -22,7 +21,7 @@ v = parse(version(project))
 version = v.base_version
 release = v.public
 
-language = None
+language = "en"
 
 exclude_patterns = ["_build"]
 pygments_style = "sphinx"
@@ -30,11 +29,10 @@ highlight_language = "python3"
 todo_include_todos = False
 
 html_theme = "sphinx_rtd_theme"
-html_static_path = ["_static"]
 htmlhelp_basename = project.replace("-", "") + "doc"
 
 intersphinx_mapping = {
     "python": ("https://docs.python.org/3/", None),
     "asphalt": ("https://asphalt.readthedocs.io/en/latest/", None),
-    "sqlalchemy": ("https://docs.sqlalchemy.org/en/14/", None),
+    "sqlalchemy": ("https://docs.sqlalchemy.org/en/20/", None),
 }
